@@ -250,9 +250,9 @@ int control_finish (struct tunnel *t, struct call *c)
             add_bearer_caps_avp (buf, t->ourbc);
             /* FIXME:  Tie breaker */
             add_firmware_avp (buf);
-            if (t->lac && t->lac->hostname && t->lac->hostname[0])
+            if (t->lac && t->lac->hostname[0])
                 add_hostname_avp (buf, t->lac->hostname);
-            else if (t->lns && t->lns->hostname && t->lns->hostname[0])
+            else if (t->lns && t->lns->hostname[0])
                 add_hostname_avp (buf, t->lns->hostname);
             else
                 add_hostname_avp (buf, hostname);
@@ -468,9 +468,9 @@ int control_finish (struct tunnel *t, struct call *c)
         add_frame_caps_avp (buf, t->ourfc);
         add_bearer_caps_avp (buf, t->ourbc);
         add_firmware_avp (buf);
-        if (t->lac && t->lac->hostname && t->lac->hostname[0])
+        if (t->lac && t->lac->hostname[0])
             add_hostname_avp (buf, t->lac->hostname);
-        else if (t->lns && t->lns->hostname && t->lns->hostname[0])
+        else if (t->lns && t->lns->hostname[0])
             add_hostname_avp (buf, t->lns->hostname);
         else
             add_hostname_avp (buf, hostname);
@@ -861,17 +861,25 @@ int control_finish (struct tunnel *t, struct call *c)
 		  c->serno, t->refme, t->refhim);
         control_xmit (buf);
         po = NULL;
+#ifndef __APPLE__
         po = add_opt (po, "passive");
         po = add_opt (po, "nodetach");
+#endif
         if (c->lac)
         {
+#ifndef __APPLE__
             if (c->lac->defaultroute)
                 po = add_opt (po, "defaultroute");
+#endif
             strncpy (ip1, IPADDY (c->lac->localaddr), sizeof (ip1));
             strncpy (ip2, IPADDY (c->lac->remoteaddr), sizeof (ip2));
 #ifdef IP_ALLOCATION
             po = add_opt (po, "%s:%s", c->lac->localaddr ? ip1 : "",
                           c->lac->remoteaddr ? ip2 : "");
+#endif
+#ifdef __APPLE__
+            if (c->lac->defaultroute)
+                po = add_opt (po, "defaultroute");
 #endif
             if (c->lac->authself)
             {
@@ -978,8 +986,10 @@ int control_finish (struct tunnel *t, struct call *c)
         strncpy (ip1, IPADDY (c->lns->localaddr), sizeof (ip1));
         strncpy (ip2, IPADDY (c->addr), sizeof (ip2));
         po = NULL;
+#ifndef __APPLE__
         po = add_opt (po, "passive");
         po = add_opt (po, "nodetach");
+#endif
         po = add_opt (po, "%s:%s", c->lns->localaddr ? ip1 : "", ip2);
         if (c->lns->authself)
         {
@@ -1032,8 +1042,10 @@ int control_finish (struct tunnel *t, struct call *c)
         break;
     case OCCN:                 /* jz: get OCCN, so the only thing we must do is to start the pppd */
         po = NULL;
+#ifndef __APPLE__
         po = add_opt (po, "passive");
         po = add_opt (po, "nodetach");
+#endif
         po = add_opt (po, "file");
         strcat (dummy_buf, c->dial_no); /* jz: use /etc/ppp/dialnumber.options for pppd - kick it if you don't like */
         strcat (dummy_buf, ".options");
@@ -1421,7 +1433,8 @@ static inline int expand_payload (struct buffer *buf, struct tunnel *t,
      * check_payload() should already be called as a prerequisite.
      */
     struct payload_hdr *h = (struct payload_hdr *) (buf->start);
-    _u16 *r = (_u16 *) h;       /* Nice to have raw word pointers */
+    typedef _u16 __attribute__((aligned(1))) _u16_ua;
+    _u16_ua *r = (_u16_ua *) h; /* Nice to have raw word pointers */
     struct payload_hdr *new_hdr;
     int ehlen = 0;
     /*
@@ -1640,7 +1653,7 @@ static inline int write_packet (struct buffer *buf, struct tunnel *t, struct cal
                  __FUNCTION__);
             return -EINVAL;
         }
-        else if ((size_t)err < 0)
+        else if ((ssize_t)err < 0)
         {
             if ((errno == EAGAIN) || (errno == EINTR))
             {
