@@ -59,7 +59,7 @@ typedef unsigned long long _u64;
 #define CONTROL_PIPE_REQ_LNS_REMOVE 'w'     /* Get status of LNS */
 
 #define BINARY "xl2tpd"
-#define SERVER_VERSION "xl2tpd-1.3.17"
+#define SERVER_VERSION "xl2tpd-1.3.20"
 #define VENDOR_NAME "xelerance.com"
 #ifndef PPPD
 #define PPPD		"/usr/sbin/pppd"
@@ -79,7 +79,7 @@ struct control_hdr
     _u16 Nr;                    /* Next received */
 } __attribute__((packed));
 
-#define CTBIT(ver) (ver & 0x8000)       /* Determins if control or not */
+#define CTBIT(ver) (ver & 0x8000)       /* Determines if control or not */
 #define CLBIT(ver) (ver & 0x4000)       /* Length bit present.  Must be 1
                                            for control messages */
 
